Camera logger
=============

Tools to record and decorate camera images to create timelapses etc.

Supported cameras
-----------------

ZWO ASI cameras are supported via the ``zwoasi`` Python module
(https://github.com/stevemarple/python-zwoasi).

Raspberry Pi cameras are supported via the PiCamera Python module.


